==> root-debug-6.36.04-6-x86_64.pkg.tar.zst: usr/src/debug/root/build-cuda/graf2d/x11ttf/G__GX11TTF.cxx <==
// Do NOT change. Changes will be lost next time file is generated

#define R__DICTIONARY_FILENAME G__GX11TTF
#define R__NO_DEPRECATION

/*******************************************************************/
#include <stddef.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <assert.h>
#define G__DICTIONARY
#include "ROOT/RConfig.hxx"
#include "TClass.h"
#include "TDictAttributeMap.h"
#include "TInterpreter.h"
#include "TROOT.h"
#include "TBuffer.h"
#include "TMemberInspector.h"
#include "TInterpreter.h"
#include "TVirtualMutex.h"
#include "TError.h"

#ifndef G__ROOT
#define G__ROOT
#endif

#include "RtypesImp.h"
#include "TIsAProxy.h"
#include "TFileMergeInfo.h"
#include <algorithm>
#include "TCollectionProxyInfo.h"
/*******************************************************************/

#include "TDataMember.h"

// Header files passed as explicit arguments
#include "TGX11TTF.h"

// Header files passed via #pragma extra_include

// The generated code does not explicitly qualify STL entities
namespace std {} using namespace std;

namespace ROOT {
   static void delete_TGX11TTF(void *p);
   static void deleteArray_TGX11TTF(void *p);
   static void destruct_TGX11TTF(void *p);
   static void streamer_TGX11TTF(TBuffer &buf, void *obj);

   // Function generating the singleton type initializer
   static TGenericClassInfo *GenerateInitInstanceLocal(const ::TGX11TTF*)
   {
      ::TGX11TTF *ptr = nullptr;
      static ::TVirtualIsAProxy* isa_proxy = new ::TInstrumentedIsAProxy< ::TGX11TTF >(nullptr);
      static ::ROOT::TGenericClassInfo 
         instance("TGX11TTF", ::TGX11TTF::Class_Version(), "TGX11TTF.h", 27,
                  typeid(::TGX11TTF), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                  &::TGX11TTF::Dictionary, isa_proxy, 16,
                  sizeof(::TGX11TTF) );
      instance.SetDelete(&delete_TGX11TTF);
      instance.SetDeleteArray(&deleteArray_TGX11TTF);
      instance.SetDestructor(&destruct_TGX11TTF);
      instance.SetStreamerFunc(&streamer_TGX11TTF);
      return &instance;
   }
   TGenericClassInfo *GenerateInitInstance(const ::TGX11TTF*)
   {
      return GenerateInitInstanceLocal(static_cast<::TGX11TTF*>(nullptr));
   }
   // Static variable to force the class initialization
   static ::ROOT::TGenericClassInfo *_R__UNIQUE_DICT_(Init) = GenerateInitInstanceLocal(static_cast<const ::TGX11TTF*>(nullptr)); R__UseDummy(_R__UNIQUE_DICT_(Init));
} // end of namespace ROOT

//______________________________________________________________________________
atomic_TClass_ptr TGX11TTF::fgIsA(nullptr);  // static to hold class pointer

//______________________________________________________________________________
const char *TGX11TTF::Class_Name()
{
   return "TGX11TTF";
}

//______________________________________________________________________________
const char *TGX11TTF::ImplFileName()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TGX11TTF*)nullptr)->GetImplFileName();
}

//______________________________________________________________________________
int TGX11TTF::ImplFileLine()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TGX11TTF*)nullptr)->GetImplFileLine();
}

//______________________________________________________________________________
TClass *TGX11TTF::Dictionary()
{
   fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TGX11TTF*)nullptr)->GetClass();
   return fgIsA;
}

//______________________________________________________________________________
TClass *TGX11TTF::Class()
{
   if (!fgIsA.load()) { R__LOCKGUARD(gInterpreterMutex); fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TGX11TTF*)nullptr)->GetClass(); }
   return fgIsA;
}

//______________________________________________________________________________
void TGX11TTF::Streamer(TBuffer &R__b)
{
   // Stream an object of class TGX11TTF.

   TGX11::Streamer(R__b);
}

namespace ROOT {
   // Wrapper around operator delete
   static void delete_TGX11TTF(void *p) {
      delete (static_cast<::TGX11TTF*>(p));
   }
   static void deleteArray_TGX11TTF(void *p) {
      delete [] (static_cast<::TGX11TTF*>(p));
   }
   static void destruct_TGX11TTF(void *p) {
      typedef ::TGX11TTF current_t;
      (static_cast<current_t*>(p))->~current_t();
   }
   // Wrapper around a custom streamer member function.
   static void streamer_TGX11TTF(TBuffer &buf, void *obj) {
      ((::TGX11TTF*)obj)->::TGX11TTF::Streamer(buf);
   }
} // end of namespace ROOT for class ::TGX11TTF

namespace ROOT {
   // Registration Schema evolution read functions
   int RecordReadRules_libGX11TTF() {
      return 0;
   }
   static int _R__UNIQUE_DICT_(ReadRules_libGX11TTF) = RecordReadRules_libGX11TTF();R__UseDummy(_R__UNIQUE_DICT_(ReadRules_libGX11TTF));
} // namespace ROOT
namespace {
  void TriggerDictionaryInitialization_libGX11TTF_Impl() {
    static const char* headers[] = {
"TGX11TTF.h",
nullptr
    };
    static const char* includePaths[] = {
"/build/root/src/build-cuda/include",
"/usr/include",
"/usr/include/freetype2",
"/usr/include",
"/usr/include/freetype2",
"/build/root/src/build-cuda/include/",
nullptr
    };
    static const char* fwdDeclCode = nullptr;
    static const char* payloadCode = nullptr;
    static const char* classesHeaders[] = {
nullptr
};
    static bool isInitialized = false;
    if (!isInitialized) {
      TROOT::RegisterModule("libGX11TTF",
        headers, includePaths, payloadCode, fwdDeclCode,
        TriggerDictionaryInitialization_libGX11TTF_Impl, {}, classesHeaders, /*hasCxxModule*/false);
      isInitialized = true;
    }
  }
  static struct DictInit {
    DictInit() {
      TriggerDictionaryInitialization_libGX11TTF_Impl();
    }
  } __TheDictionaryInitializer;
}
void TriggerDictionaryInitialization_libGX11TTF() {
  TriggerDictionaryInitialization_libGX11TTF_Impl();
}

==> root-debug-6.38.02-1-x86_64.pkg.tar.zst: usr/src/debug/root/build-cuda/graf2d/x11ttf/G__GX11TTF.cxx <==
// Do NOT change. Changes will be lost next time file is generated

#define R__DICTIONARY_FILENAME G__GX11TTF
#define R__NO_DEPRECATION

/*******************************************************************/
#include <cstddef>
#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <cassert>
#define G__DICTIONARY
#include "ROOT/RConfig.hxx"
#include "TClass.h"
#include "TDictAttributeMap.h"
#include "TInterpreter.h"
#include "TROOT.h"
#include "TBuffer.h"
#include "TMemberInspector.h"
#include "TInterpreter.h"
#include "TVirtualMutex.h"
#include "TError.h"

#ifndef G__ROOT
#define G__ROOT
#endif

#include "RtypesImp.h"
#include "TIsAProxy.h"
#include "TFileMergeInfo.h"
#include <algorithm>
#include "TCollectionProxyInfo.h"
/*******************************************************************/

#include "TDataMember.h"

// Header files passed as explicit arguments
#include "TGX11TTF.h"

// Header files passed via #pragma extra_include

// The generated code does not explicitly qualify STL entities
namespace std {} using namespace std;

namespace ROOT {
   static void delete_TGX11TTF(void *p);
   static void deleteArray_TGX11TTF(void *p);
   static void destruct_TGX11TTF(void *p);
   static void streamer_TGX11TTF(TBuffer &buf, void *obj);

   // Function generating the singleton type initializer
   static TGenericClassInfo *GenerateInitInstanceLocal(const ::TGX11TTF*)
   {
      ::TGX11TTF *ptr = nullptr;
      static ::TVirtualIsAProxy* isa_proxy = new ::TInstrumentedIsAProxy< ::TGX11TTF >(nullptr);
      static ::ROOT::TGenericClassInfo 
         instance("TGX11TTF", ::TGX11TTF::Class_Version(), "TGX11TTF.h", 27,
                  typeid(::TGX11TTF), ::ROOT::Internal::DefineBehavior(ptr, ptr),
                  &::TGX11TTF::Dictionary, isa_proxy, 16,
                  sizeof(::TGX11TTF) );
      instance.SetDelete(&delete_TGX11TTF);
      instance.SetDeleteArray(&deleteArray_TGX11TTF);
      instance.SetDestructor(&destruct_TGX11TTF);
      instance.SetStreamerFunc(&streamer_TGX11TTF);
      return &instance;
   }
   TGenericClassInfo *GenerateInitInstance(const ::TGX11TTF*)
   {
      return GenerateInitInstanceLocal(static_cast<::TGX11TTF*>(nullptr));
   }
   // Static variable to force the class initialization
   static ::ROOT::TGenericClassInfo *_R__UNIQUE_DICT_(Init) = GenerateInitInstanceLocal(static_cast<const ::TGX11TTF*>(nullptr)); R__UseDummy(_R__UNIQUE_DICT_(Init));
} // end of namespace ROOT

//______________________________________________________________________________
atomic_TClass_ptr TGX11TTF::fgIsA(nullptr);  // static to hold class pointer

//______________________________________________________________________________
const char *TGX11TTF::Class_Name()
{
   return "TGX11TTF";
}

//______________________________________________________________________________
const char *TGX11TTF::ImplFileName()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TGX11TTF*)nullptr)->GetImplFileName();
}

//______________________________________________________________________________
int TGX11TTF::ImplFileLine()
{
   return ::ROOT::GenerateInitInstanceLocal((const ::TGX11TTF*)nullptr)->GetImplFileLine();
}

//______________________________________________________________________________
TClass *TGX11TTF::Dictionary()
{
   fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TGX11TTF*)nullptr)->GetClass();
   return fgIsA;
}

//______________________________________________________________________________
TClass *TGX11TTF::Class()
{
   if (!fgIsA.load()) { R__LOCKGUARD(gInterpreterMutex); fgIsA = ::ROOT::GenerateInitInstanceLocal((const ::TGX11TTF*)nullptr)->GetClass(); }
   return fgIsA;
}

//______________________________________________________________________________
void TGX11TTF::Streamer(TBuffer &R__b)
{
   // Stream an object of class TGX11TTF.

   TGX11::Streamer(R__b);
}

namespace ROOT {
   // Wrapper around operator delete
   static void delete_TGX11TTF(void *p) {
      delete (static_cast<::TGX11TTF*>(p));
   }
   static void deleteArray_TGX11TTF(void *p) {
      delete [] (static_cast<::TGX11TTF*>(p));
   }
   static void destruct_TGX11TTF(void *p) {
      typedef ::TGX11TTF current_t;
      (static_cast<current_t*>(p))->~current_t();
   }
   // Wrapper around a custom streamer member function.
   static void streamer_TGX11TTF(TBuffer &buf, void *obj) {
      ((::TGX11TTF*)obj)->::TGX11TTF::Streamer(buf);
   }
} // end of namespace ROOT for class ::TGX11TTF

namespace ROOT {
   // Registration Schema evolution read functions
   int RecordReadRules_libGX11TTF() {
      return 0;
   }
   static int _R__UNIQUE_DICT_(ReadRules_libGX11TTF) = RecordReadRules_libGX11TTF();R__UseDummy(_R__UNIQUE_DICT_(ReadRules_libGX11TTF));
} // namespace ROOT
namespace {
  void TriggerDictionaryInitialization_libGX11TTF_Impl() {
    static const char* headers[] = {
"TGX11TTF.h",
nullptr
    };
    static const char* includePaths[] = {
"/build/root/src/build-cuda/include",
"/usr/include",
"/usr/include/freetype2",
"/build/root/src/build-cuda/include/",
nullptr
    };
    static const char* fwdDeclCode = nullptr;
    static const char* payloadCode = nullptr;
    static const char* classesHeaders[] = {
nullptr
};
    static bool isInitialized = false;
    if (!isInitialized) {
      TROOT::RegisterModule("libGX11TTF",
        headers, includePaths, payloadCode, fwdDeclCode,
        TriggerDictionaryInitialization_libGX11TTF_Impl, {}, classesHeaders, /*hasCxxModule*/false);
      isInitialized = true;
    }
  }
  static struct DictInit {
    DictInit() {
      TriggerDictionaryInitialization_libGX11TTF_Impl();
    }
  } __TheDictionaryInitializer;
}
void TriggerDictionaryInitialization_libGX11TTF() {
  TriggerDictionaryInitialization_libGX11TTF_Impl();
}
